@@ -2,7 +2,7 @@
  * Copyright (c) 2003 Riccardo Persichetti <riccardo.persichetti@tin.it>
  * Copyright (c) 2010 Florian Rivoal <frivoal@xfce.org>
  * Copyright (c) 2012 David Schneider <dnschneid@gmail.com>
- * Copyright (c) 2014-2016 Landry Breuil <landry@xfce.org>
+ * Copyright (c) 2014-2017 Landry Breuil <landry@xfce.org>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -248,6 +248,9 @@ static void
 create_monitor (t_global_monitor *global)
 {
     gint count;
+#if GTK_CHECK_VERSION (3, 16, 0)
+    GtkCssProvider *css_provider;
+#endif
 
     global->box = gtk_box_new(xfce_panel_plugin_get_orientation(global->plugin), 0);
     gtk_widget_show(global->box);
@@ -258,6 +261,20 @@ create_monitor (t_global_monitor *global)
             gtk_label_new(global->monitor[count]->options.label_text);
 
         global->monitor[count]->status = GTK_WIDGET(gtk_progress_bar_new());
+#if GTK_CHECK_VERSION (3, 16, 0)
+        css_provider = gtk_css_provider_new ();
+        gtk_style_context_add_provider (
+            GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (global->monitor[count]->status))),
+            GTK_STYLE_PROVIDER (css_provider),
+            GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+        gtk_css_provider_load_from_data (css_provider, "\
+            progressbar.horizontal trough { min-height: 4px; }\
+            progressbar.horizontal progress { min-height: 4px; }\
+            progressbar.vertical trough { min-width: 4px; }\
+            progressbar.vertical progress { min-width: 4px; }",
+             -1, NULL);
+        g_object_set_data(G_OBJECT(global->monitor[count]->status), "css_provider", css_provider);
+#endif
 
         global->monitor[count]->box = gtk_box_new(xfce_panel_plugin_get_orientation(global->plugin), 0);
 
@@ -432,7 +449,6 @@ setup_monitor(t_global_monitor *global)
 {
     gint count;
 #if GTK_CHECK_VERSION (3, 16, 0)
-    GtkCssProvider *css_provider;
     gchar * css;
 #endif
 
@@ -447,20 +463,14 @@ setup_monitor(t_global_monitor *global)
 
 #if GTK_CHECK_VERSION (3, 16, 0)
 #if GTK_CHECK_VERSION (3, 20, 0)
-        css = g_strdup_printf("progressbar trough { min-width: 4px; min-height: 4px; } \
-                               progressbar progress { min-width: 4px; min-height: 4px; \
-                                                      background-color: %s; background-image: none; }",
+        css = g_strdup_printf("progressbar progress { background-color: %s; background-image: none; }",
 #else
-        css = g_strdup_printf(".progressbar { background-color: %s; background-image: none; }",
+        css = g_strdup_printf(".progressbar progress { background-color: %s; background-image: none; }",
 #endif
-                                      gdk_rgba_to_string(&global->monitor[count]->options.color));
-        /* Setup Gtk style */
-        css_provider = gtk_css_provider_new ();
-        gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
-        gtk_style_context_add_provider (
-            GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (global->monitor[count]->status))),
-            GTK_STYLE_PROVIDER (css_provider),
-            GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+                              gdk_rgba_to_string(&global->monitor[count]->options.color));
+        gtk_css_provider_load_from_data (
+            g_object_get_data(G_OBJECT(global->monitor[count]->status), "css_provider"),
+            css, strlen(css), NULL);
         g_free(css);
 #else
         gtk_widget_override_background_color(GTK_WIDGET(global->monitor[count]->status),
@@ -973,7 +983,7 @@ monitor_show_about(XfcePanelPlugin *plugin, t_global_monitor *global)
       "program-name", PACKAGE_NAME,
       "comments", _("Monitor CPU load, swap usage and memory footprint"),
       "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-systemload-plugin",
-      "copyright", _("Copyright (c) 2003-2016\n"),
+      "copyright", _("Copyright (c) 2003-2017\n"),
       "authors", auth, NULL);
 
    if(icon)
